@@ -3,11 +3,7 @@ Soft Potato pip version
 
 """
 
-import .tech
-import .calc
-
-
-__version__ = "0.7"
+__version__ = "0.9"
 __author__ = 'Oliver Rodriguez'
 
 __all__ = ['tech', 'calc']
\ No newline at end of file
